@@ -4,6 +4,7 @@ from hugr import val
 from tket_exts import (
     debug,
     futures,
+    guppy,
     opaque_bool,
     qsystem,
     qsystem_random,
@@ -17,6 +18,7 @@ from tket_exts import (
 BOOL_EXTENSION = opaque_bool()
 DEBUG_EXTENSION = debug()
 FUTURES_EXTENSION = futures()
+GUPPY_EXTENSION = guppy()
 QSYSTEM_EXTENSION = qsystem()
 QSYSTEM_RANDOM_EXTENSION = qsystem_random()
 QSYSTEM_UTILS_EXTENSION = qsystem_utils()
@@ -29,6 +31,7 @@ TKET_EXTENSIONS = [
     BOOL_EXTENSION,
     DEBUG_EXTENSION,
     FUTURES_EXTENSION,
+    GUPPY_EXTENSION,
     QSYSTEM_EXTENSION,
     QSYSTEM_RANDOM_EXTENSION,
     QSYSTEM_UTILS_EXTENSION,
